==> neo4j-cypher-logical-plans-4.4.45-sources.jar: org/neo4j/cypher/internal/logical/plans/Foreach.scala <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.logical.plans

import org.neo4j.cypher.internal.expressions.Expression
import org.neo4j.cypher.internal.ir.SimpleMutatingPattern
import org.neo4j.cypher.internal.util.attribution.IdGen

/**
 * Foreach is an operator that performs the provided side-effects for each item in the provided list.
 */
case class Foreach(source: LogicalPlan,
                   variable: String,
                   expression: Expression,
                   mutations: Seq[SimpleMutatingPattern]
                  )(implicit idGen: IdGen)
  extends LogicalUnaryPlan(idGen) with UpdatingPlan {
  override def withLhs(newLHS: LogicalPlan)
                      (idGen: IdGen): LogicalUnaryPlan with UpdatingPlan = copy(source = newLHS)(idGen)

  override def availableSymbols: Set[String] = source.availableSymbols // NOTE: variable is not available outside
}

==> neo4j-cypher-logical-plans-5.3.0-sources.jar: org/neo4j/cypher/internal/logical/plans/Foreach.scala <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.logical.plans

import org.neo4j.cypher.internal.expressions.Expression
import org.neo4j.cypher.internal.ir.SimpleMutatingPattern
import org.neo4j.cypher.internal.util.attribution.IdGen

/**
 * Foreach is an operator that performs the provided side-effects for each item in the provided list.
 */
case class Foreach(
  source: LogicalPlan,
  variable: String,
  expression: Expression,
  mutations: collection.Seq[SimpleMutatingPattern]
)(implicit idGen: IdGen)
    extends LogicalUnaryPlan(idGen) with UpdatingPlan {

  override def withLhs(newLHS: LogicalPlan)(idGen: IdGen): LogicalUnaryPlan with UpdatingPlan =
    copy(source = newLHS)(idGen)

  override def availableSymbols: Set[String] = source.availableSymbols // NOTE: variable is not available outside
}
